@@ -96,6 +96,7 @@ void Show_About_Window (void)
     GtkWidget *ScrollWindow;
     GtkWidget *TextView;
     GtkTextBuffer *TextBuffer;
+    GtkTextIter iter;
     GtkWidget *Button;
     GtkWidget *Logo;
     GdkPixmap *pixmap;
@@ -126,6 +127,7 @@ void Show_About_Window (void)
             {"    - Patrik Israelsson ",            _("(Swedish translation)")},
             {"    - Szel Miklos ",                  _("(Hungarian translation)")},
             {"    - Nagy Boldizsar ",               _("(Hungarian translation)")},
+            {"    - Mszros Csaba ",               _("(Hungarian translation)")},
             {"    - Cappelletti Lorenzo ",          _("(Italian translation)")},
             {"    - Costantino ",                   _("(Italian translation)")},
             {"    - Takeshi Aihana ",               _("(Japanese translation)")},
@@ -171,6 +173,7 @@ void Show_About_Window (void)
             "    - Artur Polaczynski\n"
             "    - Maciej Kasprzyk\n"
             "    - Daniel Pichler\n"
+            "    - Santtu Lakkala\n"
             "    - Philipp Thomas\n"
             "    - Tony Mancill\n"
             "    - Pavel Minayev\n"
@@ -204,9 +207,11 @@ void Show_About_Window (void)
     gtk_notebook_popup_enable(GTK_NOTEBOOK(AboutNoteBook));
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(AboutWindow)->vbox),AboutNoteBook,TRUE,TRUE,0);
 
+    
     /*
      * Tab for common informations
      */
+
     Label = gtk_label_new(_("About"));
     Frame = gtk_frame_new(NULL);
     gtk_notebook_append_page (GTK_NOTEBOOK(AboutNoteBook),Frame,Label);
@@ -234,7 +239,8 @@ void Show_About_Window (void)
     }
 
     /* Infos */
-    Label = gtk_label_new(APPNAME" "VERSION);
+    Label = gtk_label_new(NULL);
+    gtk_label_set_markup(GTK_LABEL(Label),"<b>"APPNAME" "VERSION"</b>");
     gtk_box_pack_start(GTK_BOX(VBox),Label,FALSE,TRUE,0);
 
     sprintf(temp,_("(compiled: %s)"),__DATE__);
@@ -292,9 +298,11 @@ void Show_About_Window (void)
     gtk_label_set_line_wrap(GTK_LABEL(Label),TRUE);
     gtk_container_add(GTK_CONTAINER(Frame),Label);
 
+
     /*
      * Tab for thanks
      */
+
     Label = gtk_label_new(_("Thanks"));
     Frame = gtk_frame_new(NULL);
     gtk_notebook_append_page (GTK_NOTEBOOK(AboutNoteBook),Frame,Label);
@@ -306,28 +314,49 @@ void Show_About_Window (void)
                                    GTK_POLICY_AUTOMATIC,GTK_POLICY_AUTOMATIC);
 
     TextBuffer = gtk_text_buffer_new(NULL);
+    gtk_text_buffer_create_tag(TextBuffer, "italic", "style", PANGO_STYLE_ITALIC, NULL);
+    gtk_text_buffer_create_tag(TextBuffer, "bold", "weight", PANGO_WEIGHT_BOLD, NULL);
+    gtk_text_buffer_create_tag(TextBuffer, "underline", "underline", PANGO_UNDERLINE_SINGLE, NULL);
+    gtk_text_buffer_create_tag(TextBuffer, "large", "scale", PANGO_SCALE_LARGE, NULL);
+    //gtk_text_buffer_create_tag(TextBuffer, "x-large", "scale", PANGO_SCALE_X_LARGE, NULL);
+    //gtk_text_buffer_create_tag(TextBuffer, "monospace", "family", "monospace", NULL);
+
+    gtk_text_buffer_get_iter_at_offset(TextBuffer, &iter, 0);
+
     temp_str = _("Translations:\n");
-    gtk_text_buffer_insert_at_cursor(TextBuffer, temp_str, g_utf8_strlen(temp_str, -1));
+    gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &iter, 
+                                             temp_str, -1,
+                                             "bold", "underline", "large", NULL);
+
     for (i=0; translations_thanks_text[i][0]!=NULL; i++)
     {
-        temp_str = g_strconcat(translations_thanks_text[i][0],translations_thanks_text[i][1],NULL);
-        if (!g_utf8_validate(temp_str, -1, NULL))
-        {
-            tmp = convert_string(temp_str, "iso-8859-1", "utf-8");
-            g_free(temp_str);
-            temp_str = tmp;
-        }
-        gtk_text_buffer_insert_at_cursor(TextBuffer, temp_str, -1);
-        gtk_text_buffer_insert_at_cursor(TextBuffer, "\r\n", -1);
+        // Translator name
+        if (!g_utf8_validate(translations_thanks_text[i][0], -1, NULL))
+            temp_str = convert_string(translations_thanks_text[i][0], "iso-8859-1", "utf-8");
+        else
+            temp_str = g_strdup(translations_thanks_text[i][0]);
+        gtk_text_buffer_insert(TextBuffer, &iter, temp_str, -1);
         g_free(temp_str);
+
+        // Translation language
+        if (!g_utf8_validate(translations_thanks_text[i][1], -1, NULL))
+            temp_str = convert_string(translations_thanks_text[i][1], "iso-8859-1", "utf-8");
+        else
+            temp_str = g_strdup(translations_thanks_text[i][1]);
+        gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &iter, temp_str, -1,
+                                                 "italic", NULL);
+        g_free(temp_str);
+        gtk_text_buffer_insert(TextBuffer, &iter, "\n", -1);
     }
 
-    gtk_text_buffer_insert_at_cursor(TextBuffer, "\n", 1);
+    gtk_text_buffer_insert(TextBuffer, &iter, "\n", -1);
 
     temp_str = _("General:\n");
-    gtk_text_buffer_insert_at_cursor(TextBuffer, temp_str, g_utf8_strlen(temp_str, -1));
-    gtk_text_buffer_insert_at_cursor(TextBuffer, "\r\n", -1);
-    gtk_text_buffer_insert_at_cursor(TextBuffer, general_thanks_text, g_utf8_strlen(general_thanks_text, -1));
+    gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &iter, 
+                                             temp_str, -1,
+                                             "bold", "underline", "large", NULL);
+    gtk_text_buffer_insert(TextBuffer, &iter, general_thanks_text, -1);
+    
     TextView = gtk_text_view_new_with_buffer(TextBuffer);
     gtk_container_add(GTK_CONTAINER(ScrollWindow),TextView);
     gtk_text_view_set_editable(GTK_TEXT_VIEW(TextView), FALSE);
@@ -350,28 +379,62 @@ void Show_About_Window (void)
                                    GTK_POLICY_AUTOMATIC,GTK_POLICY_AUTOMATIC);
 
     TextBuffer = gtk_text_buffer_new(NULL);
+    gtk_text_buffer_get_iter_at_offset(TextBuffer, &iter, 0);
+    gtk_text_buffer_create_tag(TextBuffer, "monospace", "family", "monospace", NULL);
+    gtk_text_buffer_create_tag(TextBuffer, "red_foreground", "foreground", "red", NULL);
+    gtk_text_buffer_create_tag(TextBuffer, "blue_foreground", "foreground", "blue", NULL);
+    gtk_text_buffer_create_tag(TextBuffer, "bold", "weight", PANGO_WEIGHT_BOLD, NULL);
+
+    gtk_text_buffer_get_iter_at_offset(TextBuffer, &iter, 0);
+
     // The file 'ChangeLog' to read
     if ( (file=fopen(PACKAGE_DATA_DIR"/ChangeLog","r"))==0 )
     {
         gchar *msg = g_strdup_printf(_("Can't open file '%s' (%s)\n"),PACKAGE_DATA_DIR"/ChangeLog",g_strerror(errno));
-        gtk_text_buffer_insert_at_cursor(TextBuffer, msg, g_utf8_strlen(msg, -1));
+        gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &iter, 
+                                                 msg, -1,
+                                                 "monospace", "red_foreground", NULL);
         g_free(msg);
     } else 
     {
+        gint first_version = 0;
+        
         while(fgets(temp,sizeof(temp),file))
         {
             if (temp[strlen(temp)-1]=='\n')
                 temp[strlen(temp)-1]='\0';
             if (temp[strlen(temp)-1]=='\r')
                 temp[strlen(temp)-1]='\0';
-            // don't use font yet....
+
             if (!g_utf8_validate(temp, -1, NULL))
                 tmp = convert_string(temp, "iso-8859-1", "utf-8");
             else
                 tmp = g_strdup(temp);
 
-            gtk_text_buffer_insert_at_cursor(TextBuffer, tmp, -1);
-            gtk_text_buffer_insert_at_cursor(TextBuffer, "\r\n", -1);
+            if (tmp && tmp[0]!=' ')
+            {
+                first_version++;
+                // To set to bold the title of the version and to red the first version
+                if (first_version > 2) // As title takes 2 lines
+                    gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &iter, 
+                                                             tmp, -1,
+                                                             "monospace", "bold", NULL);
+                else
+                    gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &iter, 
+                                                             tmp, -1,
+                                                             "monospace", "bold", "blue_foreground", NULL);
+            }else
+            {
+                if (first_version > 2) // As title takes 2 lines
+                    gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &iter, 
+                                                             tmp, -1,
+                                                             "monospace", NULL);
+                else
+                    gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &iter, 
+                                                             tmp, -1,
+                                                             "monospace", "blue_foreground", NULL);
+            }
+            gtk_text_buffer_insert(TextBuffer, &iter, "\n", -1);
             g_free(tmp);
         }
         fclose(file);
