@@ -1,7 +1,7 @@
 /* flac_header.c - 2002/07/03 */
 /*
  *  EasyTAG - Tag editor for MP3 and Ogg Vorbis files
- *  Copyright (C) 2000-2003  Jerome Couderc <j.couderc@ifrance.com>
+ *  Copyright (C) 2000-2003  Jerome Couderc <easytag@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 #ifdef ENABLE_FLAC
 
 #include <gtk/gtk.h>
+#include <glib/gi18n-lib.h>
 #include <stdio.h>
 #include <errno.h>
 #include <string.h>    // 20030519 <tmancill@debian.org> for compiliation on ia64 arch
@@ -38,8 +39,7 @@
 #include "easytag.h"
 #include "et_core.h"
 #include "misc.h"
-#include "i18n.h"
-
+#include "charset.h"
 
 
 
@@ -98,21 +98,23 @@ gboolean Flac_Header_Read_File_Info (gchar *filename, ET_File_Info *ETFileInfo)
     FLAC__FileDecoder *tmp_decoder;
     file_info_struct tmp_file_info;
 
-
     if (!filename || !ETFileInfo)
         return FALSE;
 
     if ( (file=fopen(filename,"r"))==NULL )
     {
-        g_print(_("ERROR while opening file: '%s' (%s)\n\a"),filename,g_strerror(errno));
+        gchar *filename_utf8 = filename_to_display(filename);
+        g_print(_("ERROR while opening file: '%s' (%s)\n\a"),filename_utf8,g_strerror(errno));
+        g_free(filename_utf8);
         return FALSE;
     }
     fclose(file);
 
     /* Decoding FLAC file */
     tmp_decoder = FLAC__file_decoder_new();
-    if(tmp_decoder == 0)
+    if (tmp_decoder == 0) {
         return FALSE;
+    }
 
     tmp_file_info.abort_flag = false;
     FLAC__file_decoder_set_md5_checking     (tmp_decoder, false);
@@ -121,17 +123,19 @@ gboolean Flac_Header_Read_File_Info (gchar *filename, ET_File_Info *ETFileInfo)
     FLAC__file_decoder_set_metadata_callback(tmp_decoder, metadata_callback_);
     FLAC__file_decoder_set_error_callback   (tmp_decoder, error_callback_);
     FLAC__file_decoder_set_client_data      (tmp_decoder, &tmp_file_info);
-    if(FLAC__file_decoder_init(tmp_decoder) != FLAC__FILE_DECODER_OK)
+    if (FLAC__file_decoder_init(tmp_decoder) != FLAC__FILE_DECODER_OK) {
         return FALSE;
+    }
 
     // In FLAC 1.0.3, is used : FLAC__file_decoder_process_metadata
     // In FLAC 1.0.4, is used : FLAC__file_decoder_process_until_end_of_metadata
 #if ( (LIBFLAC_MAJOR <= 1) && (LIBFLAC_MINOR <= 0) && (LIBFLAC_PATCH <= 3) )
-    if(!FLAC__file_decoder_process_metadata(tmp_decoder)) // FLAC 1.0.3
+    if (!FLAC__file_decoder_process_metadata(tmp_decoder)) { // FLAC 1.0.3
 #else
-    if(!FLAC__file_decoder_process_until_end_of_metadata(tmp_decoder)) // FLAC 1.0.4 (Bastian Kleineidam)
+    if (!FLAC__file_decoder_process_until_end_of_metadata(tmp_decoder)) { // FLAC 1.0.4 (Bastian Kleineidam)
 #endif
         return FALSE;
+    }
 
     FLAC__file_decoder_finish(tmp_decoder);
     FLAC__file_decoder_delete(tmp_decoder);
@@ -164,15 +168,15 @@ FLAC__StreamDecoderWriteStatus write_callback_(const FLAC__FileDecoder *decoder,
 
     (void)decoder;
 
-    if(file_info->abort_flag)
+    if (file_info->abort_flag)
         return FLAC__STREAM_DECODER_WRITE_STATUS_ABORT;
 
-    if(bps == 8) {
+    if (bps == 8) {
         for(sample = reservoir_samples_*channels, wide_sample = 0; wide_sample < wide_samples; wide_sample++)
             for(channel = 0; channel < channels; channel++, sample++)
                 scbuffer[sample] = (FLAC__int8)buffer[channel][wide_sample];
     }
-    else if(bps == 16) {
+    else if (bps == 16) {
         for(sample = reservoir_samples_*channels, wide_sample = 0; wide_sample < wide_samples; wide_sample++)
             for(channel = 0; channel < channels; channel++, sample++)
                 ssbuffer[sample] = (FLAC__int16)buffer[channel][wide_sample];
@@ -191,17 +195,17 @@ void metadata_callback_(const FLAC__FileDecoder *decoder, const FLAC__StreamMeta
 {
     file_info_struct *file_info = (file_info_struct *)client_data;
     (void)decoder;
-    if(metadata->type == FLAC__METADATA_TYPE_STREAMINFO) {
+    if (metadata->type == FLAC__METADATA_TYPE_STREAMINFO) {
         FLAC__ASSERT(metadata->data.stream_info.total_samples < 0x100000000); /* this plugin can only handle < 4 gigasamples */
         file_info->total_samples = (unsigned)(metadata->data.stream_info.total_samples&0xffffffff);
         file_info->bits_per_sample = metadata->data.stream_info.bits_per_sample;
         file_info->channels = metadata->data.stream_info.channels;
         file_info->sample_rate = metadata->data.stream_info.sample_rate;
 
-        if(file_info->bits_per_sample == 8) {
+        if (file_info->bits_per_sample == 8) {
             file_info->sample_format = FMT_S8;
         }
-        else if(file_info->bits_per_sample == 16) {
+        else if (file_info->bits_per_sample == 16) {
             file_info->sample_format = FMT_S16_NE;
         }
         else {
@@ -216,14 +220,14 @@ void error_callback_(const FLAC__FileDecoder *decoder, FLAC__StreamDecoderErrorS
 {
     file_info_struct *file_info = (file_info_struct *)client_data;
     (void)decoder;
-    if(status != FLAC__STREAM_DECODER_ERROR_STATUS_LOST_SYNC)
+    if (status != FLAC__STREAM_DECODER_ERROR_STATUS_LOST_SYNC)
         file_info->abort_flag = true;
 }
 
 
 
 
-gboolean Flac_Header_Display_File_Info_To_UI (gchar *filename, ET_File_Info *ETFileInfo)
+gboolean Flac_Header_Display_File_Info_To_UI (gchar *filename_utf8, ET_File_Info *ETFileInfo)
 {
     gchar *text;
     gchar *time = NULL;
@@ -258,8 +262,8 @@ gboolean Flac_Header_Display_File_Info_To_UI (gchar *filename, ET_File_Info *ETF
     size1 = Convert_Size(ETCore->ETFileDisplayedList_TotalSize);
     text  = g_strdup_printf("%s (%s)",size,size1);
     gtk_label_set_text(GTK_LABEL(SizeValueLabel),text);
-    if (size)  g_free(size);
-    if (size1) g_free(size1);
+    g_free(size);
+    g_free(size1);
     g_free(text);
 
     /* Duration */
@@ -267,8 +271,8 @@ gboolean Flac_Header_Display_File_Info_To_UI (gchar *filename, ET_File_Info *ETF
     time1 = Convert_Duration(ETCore->ETFileDisplayedList_TotalDuration);
     text  = g_strdup_printf("%s (%s)",time,time1);
     gtk_label_set_text(GTK_LABEL(DurationValueLabel),text);
-    if (time)  g_free(time);
-    if (time1) g_free(time1);
+    g_free(time);
+    g_free(time1);
     g_free(text);
 
     return TRUE;
