@@ -911,6 +911,7 @@ apetag_save (char *filename, apetag *mem_cnt, int flag)
     int id3v1;
     int apeTag, saveApe2;
     int tagCount = 0;
+    int realCountTag = 0;
     struct _apetag_footer ape_footer;
     long skipBytes;
     unsigned char *buff, *p;
@@ -954,6 +955,7 @@ apetag_save (char *filename, apetag *mem_cnt, int flag)
         if (mTag[n]->sizeValue != 0) {
             tagSSize += ((long) mTag[n]->sizeName + (long) mTag[n]->sizeValue);
             tagSSize += 4 + 4 + 1 + (saveApe2 ? 0 : 1);    // flag & sizeValue & \0
+            realCountTag++; // count not deleted tag (exl. not real)
         }
     }
     if (!!(flag & SAVE_CREATE_ID3V1_TAG )) {
@@ -976,7 +978,8 @@ apetag_save (char *filename, apetag *mem_cnt, int flag)
         long2ape (ape_footer.length, tagSSize-128);
     else
         long2ape (ape_footer.length, tagSSize);
-    long2ape (ape_footer.tagCount, mem_cnt->countTag);
+    //long2ape(ape_footer.tagCount, mem_cnt->countTag);
+    long2ape(ape_footer.tagCount, realCountTag);
     long2ape (ape_footer.version, (saveApe2 ? 2000 : 1000));
     if (saveApe2) {
         long2ape (ape_footer.flags, HEADER_THIS_IS + HEADER_IS + FOOTER_IS);
