@@ -1,7 +1,7 @@
 /* mpeg_header.c - 2000/05/12 */
 /*
  *  EasyTAG - Tag editor for MP3 and Ogg Vorbis files
- *  Copyright (C) 2000-2003  Jerome Couderc <j.couderc@ifrance.com>
+ *  Copyright (C) 2000-2003  Jerome Couderc <easytag@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +18,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#include <config.h>
 
 #include <gtk/gtk.h>
+#include <glib/gi18n-lib.h>
 #include <stdio.h>
 #include <errno.h>
 #include <unistd.h>
@@ -28,8 +30,7 @@
 #include "easytag.h"
 #include "et_core.h"
 #include "misc.h"
-#include "i18n.h"
-
+#include "charset.h"
 #include "libmpg123/mpg123.h"
 
 
@@ -199,7 +200,9 @@ gboolean Mpeg_Header_Read_File_Info (gchar *filename, ET_File_Info *ETFileInfo)
         fclose(file);
     }else
     {
-        g_print(_("ERROR while opening file: '%s' (%s).\n\a"),filename,g_strerror(errno));
+        gchar *filename_utf8 = filename_to_display(filename);
+        g_print(_("ERROR while opening file: '%s' (%s).\n\a"),filename_utf8,g_strerror(errno));
+        g_free(filename_utf8);
         return FALSE;
     }
 
@@ -211,7 +214,7 @@ gboolean Mpeg_Header_Read_File_Info (gchar *filename, ET_File_Info *ETFileInfo)
 /*
  * Display header infos in the main window
  */
-gboolean Mpeg_Header_Display_File_Info_To_UI(gchar *filename, ET_File_Info *ETFileInfo)
+gboolean Mpeg_Header_Display_File_Info_To_UI(gchar *filename_utf8, ET_File_Info *ETFileInfo)
 {
     gchar *text;
     gchar *time = NULL;
@@ -255,8 +258,8 @@ gboolean Mpeg_Header_Display_File_Info_To_UI(gchar *filename, ET_File_Info *ETFi
     size1 = Convert_Size(ETCore->ETFileDisplayedList_TotalSize);
     text  = g_strdup_printf("%s (%s)",size,size1);
     gtk_label_set_text(GTK_LABEL(SizeValueLabel),text);
-    if (size)  g_free(size);
-    if (size1) g_free(size1);
+    g_free(size);
+    g_free(size1);
     g_free(text);
 
     /* Duration */
@@ -264,8 +267,8 @@ gboolean Mpeg_Header_Display_File_Info_To_UI(gchar *filename, ET_File_Info *ETFi
     time1 = Convert_Duration(ETCore->ETFileDisplayedList_TotalDuration);
     text  = g_strdup_printf("%s (%s)",time,time1);
     gtk_label_set_text(GTK_LABEL(DurationValueLabel),text);
-    if (time)  g_free(time);
-    if (time1) g_free(time1);
+    g_free(time);
+    g_free(time1);
     g_free(text);
 
     return TRUE;
