@@ -174,6 +174,7 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     /*********
      * Title *
      *********/
+    /* Note : don't forget to add any new field to 'Save unsupported fields' */
     field_num = 0;
     while ( (string = vorbis_comment_query(vc,"TITLE",field_num++)) != NULL )
     {
@@ -392,6 +393,7 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
           && strncasecmp(vc->user_comments[i],"DISCNUMBER=", 11) != 0
           && strncasecmp(vc->user_comments[i],"DATE=",        5) != 0
           && strncasecmp(vc->user_comments[i],"TRACKNUMBER=",12) != 0
+          && strncasecmp(vc->user_comments[i],"TRACKTOTAL=", 11) != 0
           && strncasecmp(vc->user_comments[i],"GENRE=",       6) != 0
           && strncasecmp(vc->user_comments[i],"COMMENT=",     8) != 0
           && strncasecmp(vc->user_comments[i],"=",            1) != 0
