@@ -180,14 +180,41 @@ void Picture_Load_Filename (gchar *filename, gpointer user_data)
 {
     Picture *pic;
     gchar *filename_utf8;
+    gchar *filename_utf8_folded = NULL;
+    gchar *front_folded = NULL;
+    gchar *back_folded = NULL;
+    gchar *cd_folded = NULL;
+    gchar *inside_folded = NULL;
+    //gchar *inlay_folded = NULL;
     
+    // Filename must be passed in filesystem encoding!
+    pic = Picture_Load_File_Data(filename);
+
     filename_utf8 = filename_to_display(filename);
-    pic = Picture_Load_File_Data(filename_utf8);
     
-    if (pic)
+    if (pic && filename_utf8)
     {
         // By default, set the filename in the description
-        pic->description = g_path_get_basename(filename_utf8); 
+        pic->description = g_path_get_basename(filename_utf8);
+        
+        // Try to identify the type of the picture from the file name
+        filename_utf8_folded = g_utf8_casefold(pic->description, -1);
+        front_folded         = g_utf8_casefold("Front", -1);
+        back_folded          = g_utf8_casefold("Back", -1);
+        cd_folded            = g_utf8_casefold("CD", -1);
+        inside_folded        = g_utf8_casefold("inside", -1);
+        //inlay_folded         = g_utf8_casefold("inlay", -1);
+        if ( strstr(filename_utf8_folded, front_folded) != NULL )
+            pic->type = PICTURE_TYPE_FRONT_COVER;
+        else if ( strstr(filename_utf8_folded, back_folded) != NULL )
+            pic->type = PICTURE_TYPE_BACK_COVER;
+        else if ( strstr(filename_utf8_folded, cd_folded) != NULL )
+            pic->type = PICTURE_TYPE_MEDIA;
+        else if ( strstr(filename_utf8_folded, inside_folded) != NULL )
+            pic->type = PICTURE_TYPE_LEAFLET_PAGE;
+        //else if ( strstr(filename_utf8_folded, inlay_folded) != NULL )
+        //    pic->type = PICTURE_TYPE_LEAFLET_PAGE;
+
         PictureEntry_Update(pic, 1);
 
         // FIXME: Call Picture_Free(pic) here? It seems PictureEntry_Update makes copies of pic.
@@ -195,6 +222,12 @@ void Picture_Load_Filename (gchar *filename, gpointer user_data)
     }
     
     g_free(filename_utf8);
+    g_free(filename_utf8_folded);
+    g_free(front_folded);
+    g_free(back_folded);
+    g_free(cd_folded);
+    g_free(inside_folded);
+    //g_free(inlay_folded);
 }
 
 /*
@@ -418,7 +451,8 @@ void Picture_Properties_Button_Clicked (GObject *object)
                 gchar *buffer, *pic_info;
                 gint t;
                 
-                gtk_tree_model_get(modeltype, &itertype, 1, &t, -1); // Get cell 1 value
+                gtk_tree_model_get(modeltype, &itertype,
+                                   PICTURE_TYPE_COLUMN_TYPE_CODE, &t, -1);
                 pic->type = t;
     
                 buffer = g_strdup(gtk_entry_get_text(GTK_ENTRY(desc)));
@@ -434,7 +468,7 @@ void Picture_Properties_Button_Clicked (GObject *object)
                     g_free(buffer);
                 }
                 
-                // Update value in the Picture view
+                // Update value in the PictureEntryView
                 pic_info = Picture_Info(pic);
                 gtk_list_store_set(GTK_LIST_STORE(model), &iter,
                                    PICTURE_COLUMN_TEXT, pic_info,
@@ -450,211 +484,6 @@ void Picture_Properties_Button_Clicked (GObject *object)
 }
 
 
-/************
-void save_selected_pic (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gchar *filename)
-{
-    Picture *pic;
-    
-    gtk_tree_model_get(model, iter, PICTURE_COLUMN_DATA, &pic, -1);
-    Picture_Save_File_Data(pic, filename);
-}
-
-void get_selected_pic (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, GtkTreeIter *iter_set)
-{
-    *iter_set = *iter;
-}
-
-void Picture_Properties_Button_Clicked (GObject *object)
-{
-    GtkWidget *dialog, *type, *label, *desc;
-    GtkWidget *ScrollWindowPictureTypes;
-    GtkCellRenderer *renderer;
-    GtkTreeViewColumn *column;
-    GtkTreeSelection *selection;
-    GtkListStore *store;
-    Picture *pic;
-    GtkTreeModel *model2;
-    GtkTreeIter iter2, default_type_iter;
-    GtkWindow *parent_window = NULL;
-    
-    gint picture_types[] = 
-        {
-            PICTURE_TYPE_OTHER,
-            PICTURE_TYPE_FILE_ICON,
-            PICTURE_TYPE_OTHER_FILE_ICON,
-            PICTURE_TYPE_FRONT_COVER,
-            PICTURE_TYPE_BACK_COVER,
-            PICTURE_TYPE_LEAFLET_PAGE,
-            PICTURE_TYPE_MEDIA,
-            PICTURE_TYPE_LEAD_ARTIST_LEAD_PERFORMER_SOLOIST,
-            PICTURE_TYPE_ARTIST_PERFORMER,
-            PICTURE_TYPE_CONDUCTOR,
-            PICTURE_TYPE_BAND_ORCHESTRA,
-            PICTURE_TYPE_COMPOSER,
-            PICTURE_TYPE_LYRICIST_TEXT_WRITER,
-            PICTURE_TYPE_RECORDING_LOCATION,
-            PICTURE_TYPE_DURING_RECORDING,
-            PICTURE_TYPE_DURING_PERFORMANCE,
-            PICTURE_TYPE_MOVIDE_VIDEO_SCREEN_CAPTURE,
-            PICTURE_TYPE_A_BRIGHT_COLOURED_FISH,
-            PICTURE_TYPE_ILLUSTRATION,
-            PICTURE_TYPE_BAND_ARTIST_LOGOTYPE,
-            PICTURE_TYPE_PUBLISHER_STUDIO_LOGOTYPE
-        };
-    gint i;
-    
-    parent_window = (GtkWindow *) gtk_widget_get_toplevel(GTK_WIDGET(object));
-    if (!GTK_WIDGET_TOPLEVEL(parent_window))
-    {
-        g_warning("Could not get parent window\n");
-        return;
-    }
-
-    model2 = gtk_tree_view_get_model(GTK_TREE_VIEW(PictureEntryView));
-    gtk_tree_selection_selected_foreach(gtk_tree_view_get_selection(GTK_TREE_VIEW(PictureEntryView)),
-                                        (GtkTreeSelectionForeachFunc) get_selected_pic, &iter2);
-    gtk_tree_model_get(model2, &iter2, PICTURE_COLUMN_DATA, &pic, -1);
-    
-    dialog = gtk_dialog_new_with_buttons(_("Picture Properties"),
-                                         parent_window,
-                                         GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                                         GTK_STOCK_CANCEL,
-                                         GTK_RESPONSE_REJECT,
-                                         GTK_STOCK_OK,
-                                         GTK_RESPONSE_ACCEPT,
-                                         NULL);
-
-    // Set window position
-    if (MESSAGE_BOX_POSITION_NONE)
-        gtk_window_set_position(GTK_WINDOW(dialog),GTK_WIN_POS_NONE);
-    else if (MESSAGE_BOX_POSITION_CENTER)
-        gtk_window_set_position(GTK_WINDOW(dialog),GTK_WIN_POS_CENTER);
-    else if (MESSAGE_BOX_POSITION_MOUSE)
-        gtk_window_set_position(GTK_WINDOW(dialog),GTK_WIN_POS_MOUSE);
-
-    ScrollWindowPictureTypes = gtk_scrolled_window_new(NULL, NULL);
-    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(ScrollWindowPictureTypes),
-                                   GTK_POLICY_AUTOMATIC,
-                                   GTK_POLICY_AUTOMATIC);
-    store = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_INT);
-    type = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
-    gtk_container_add(GTK_CONTAINER(ScrollWindowPictureTypes), type);
-    
-    renderer = gtk_cell_renderer_text_new();
-    column = gtk_tree_view_column_new();
-    gtk_tree_view_column_pack_start(column, renderer, FALSE);
-    gtk_tree_view_column_set_title(column, _("Picture Type"));
-    gtk_tree_view_column_set_attributes(column, renderer,
-                                        "text", 0,
-                                        NULL);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(type), column);
-    gtk_widget_set_size_request(type, 256, 256);
-    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox),ScrollWindowPictureTypes,TRUE,TRUE,0);
-
-    // Load pictures types
-    for (i = 0; i < sizeof(picture_types)/sizeof(picture_types[0]); i++)
-    {
-          GtkTreeIter iter;
-          
-          gtk_list_store_append(store, &iter);
-          gtk_list_store_set(store, &iter,
-                             0, _(Picture_Type_String(picture_types[i])),
-                             1, picture_types[i],
-                             -1);
-          if (pic->type == picture_types[i])
-              default_type_iter = iter;
-    }
-
-    label = gtk_label_new(_("Picture Description:"));
-    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox),label,FALSE,FALSE,4);
-
-    // Entry for the description
-    desc = gtk_entry_new();
-    if (pic->description)
-        gtk_entry_set_text(GTK_ENTRY(desc), pic->description);
-    
-    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox),desc,FALSE,FALSE,0);
-
-    gtk_widget_show_all(dialog);
-    gtk_tree_selection_select_iter(gtk_tree_view_get_selection(GTK_TREE_VIEW(type)),
-                                   &default_type_iter);
-    
-    if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT)
-    {
-        GtkTreeModel *model;
-        GtkTreeIter iter;
-        
-        model = gtk_tree_view_get_model(GTK_TREE_VIEW(type));
-        selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(type));
-        if (gtk_tree_selection_get_selected(selection, &model, &iter))
-        {
-            gchar *buffer;
-            gint t;
-            
-            gtk_tree_model_get(model, &iter, 1, &t, -1);
-            pic->type = t;
-
-            buffer = g_strdup(gtk_entry_get_text(GTK_ENTRY(desc)));
-            Strip_String(buffer);
-            if (pic->description)
-                g_free(pic->description);
-            if ( g_utf8_strlen(buffer, -1) > 0 )
-            {
-                pic->description = buffer;
-            }else
-            {
-                pic->description = 0;
-                g_free(buffer);
-            }
-            
-            gtk_list_store_set(GTK_LIST_STORE(model2), &iter2,
-                               PICTURE_TEXT_COLUMN, Picture_Info(pic),
-                               -1);
-        }
-    }
-    gtk_widget_destroy(dialog);
-}
-
-void Picture_Save_Button_Clicked (GObject *object)
-{
-    GtkWidget *FileSelectionWindow;
-    GtkWindow *parent_window = NULL;
-    static gchar *init_dir = NULL;
-
-    parent_window = (GtkWindow*) gtk_widget_get_toplevel(GTK_WIDGET(object));
-    if (!GTK_WIDGET_TOPLEVEL(parent_window))
-    {
-        g_warning("Could not get parent window\n");
-        return;
-    }
-
-    FileSelectionWindow = gtk_file_chooser_dialog_new(_("Save picture"),
-                                                      parent_window,
-                                                      GTK_FILE_CHOOSER_ACTION_SAVE,
-                                                      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                                      GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
-                                                      NULL);
-    // Set the default folder if defined
-    if (init_dir)
-        gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(FileSelectionWindow),init_dir);
-
-    if (gtk_dialog_run(GTK_DIALOG(FileSelectionWindow)) == GTK_RESPONSE_ACCEPT)
-    {
-        gchar *filename, *filename_utf8;
-    
-        filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(FileSelectionWindow));
-        filename_utf8 = filename_to_display(filename);
-        gtk_tree_selection_selected_foreach(gtk_tree_view_get_selection(GTK_TREE_VIEW(PictureEntryView)),
-            (GtkTreeSelectionForeachFunc) save_selected_pic, filename_utf8);
-        g_free(filename_utf8);
-
-        // Save the directory selected for initialize next time
-        g_free(init_dir);
-        init_dir = gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER(FileSelectionWindow));
-    }
-    gtk_widget_destroy(FileSelectionWindow);
-}
-*********/
 void Picture_Save_Button_Clicked (GObject *object)
 {
     GtkWidget *FileSelectionWindow;
@@ -1061,6 +890,10 @@ void Picture_Free (Picture *pic)
 
 #define LOAD_BUFFER_SIZE 4096
 
+/*
+ * Load the picture represented by the 'filename' (must be passed in
+ * file system encoding, not UTF-8)
+ */
 Picture *Picture_Load_File_Data (const gchar *filename)
 {
     Picture *pic;
@@ -1070,7 +903,25 @@ Picture *Picture_Load_File_Data (const gchar *filename)
     
     fd = open(filename, O_RDONLY);
     if (fd == -1)
+    {
+        gchar *msg;
+        gchar *filename_utf8;
+        GtkWidget *msgbox;
+
+        /* Picture file not opened */
+        filename_utf8 = filename_to_display(filename);
+        msg = g_strdup_printf(_("Can't open file :\n'%s'!\n(%s)"),
+                                filename_utf8,g_strerror(errno)); 
+        msgbox = msg_box_new (_("Error..."),msg,GTK_STOCK_DIALOG_ERROR,BUTTON_OK,0);
+        g_free(msg);
+        msg_box_hide_check_button(MSG_BOX(msgbox));
+        msg_box_run(MSG_BOX(msgbox));
+        gtk_widget_destroy(msgbox);
+
+        Statusbar_Message(_("Picture file not loaded..."),TRUE);
+        g_free(filename_utf8);
         return FALSE;
+    }
     
     do
     {
