@@ -516,6 +516,7 @@ void Open_OptionsWindow (void)
     gtk_container_add(GTK_CONTAINER(EventBox),SortingFileCombo);
     gtk_box_pack_start(GTK_BOX(hbox),EventBox,FALSE,FALSE,2);
     gtk_widget_set_size_request(GTK_WIDGET(SortingFileCombo), 260, -1);
+    gtk_combo_box_set_wrap_width(GTK_COMBO_BOX(SortingFileCombo),2); // Two columns
 
     // Items of option menu
     gtk_combo_box_append_text(GTK_COMBO_BOX(SortingFileCombo), _("Ascending file name"));
@@ -798,13 +799,14 @@ void Open_OptionsWindow (void)
     gtk_container_set_border_width(GTK_CONTAINER(vbox),2);
     
     // Don't convert some words like to, feat. first letter uppercase.
-    PFSDontUpperSomeWords = gtk_check_button_new_with_label(_("Don't uppercase first letter "
-        "of words for some prepositions and articles."));
+    PFSDontUpperSomeWords = gtk_check_button_new_with_label(_("Don't uppercase "
+        "first letter of words for some prepositions and articles."));
     gtk_box_pack_start(GTK_BOX(vbox),PFSDontUpperSomeWords, FALSE, FALSE, 0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(PFSDontUpperSomeWords), PFS_DONT_UPPER_SOME_WORDS);
-    gtk_tooltips_set_tip(Tips, PFSDontUpperSomeWords, _("Don't convert first letter of the "
-        "words like prepositions, articles and  words like feat., when using the scanner "
-        "'First letter uppercase of each word'."), NULL);
+    gtk_tooltips_set_tip(Tips, PFSDontUpperSomeWords, _("Don't convert first "
+        "letter of the words like prepositions, articles and words like feat., "
+        "when using the scanner 'First letter uppercase of each word' (for "
+        "example, you will obtain 'Text in an Entry' instead of 'Text In An Entry')."), NULL);
 
     /* Properties of the scanner window */
     Frame = gtk_frame_new (_("Scanner Window"));
@@ -851,7 +853,7 @@ void Open_OptionsWindow (void)
     gtk_entry_set_max_length(GTK_ENTRY(ScannerWindowY), 5);
     gtk_box_pack_start(GTK_BOX(hbox),ScannerWindowY,FALSE,FALSE,0);
     gtk_widget_set_size_request(ScannerWindowY, 40, -1);
-    ScannerWindowButton = Create_Button_With_Icon_And_Label("esaytag-grab",_(" Get current position "));
+    ScannerWindowButton = Create_Button_With_Icon_And_Label("easytag-grab",_(" Get current position "));
     gtk_box_pack_start(GTK_BOX(hbox),ScannerWindowButton,FALSE,FALSE,0);
     g_signal_connect(G_OBJECT(ScannerWindowButton),"clicked",
         G_CALLBACK(Get_Scanner_Window_Position),NULL);
@@ -1107,18 +1109,25 @@ void Open_OptionsWindow (void)
     gtk_container_add(GTK_CONTAINER(Frame),vbox);
     gtk_container_set_border_width(GTK_CONTAINER(vbox), 4);
 
-    CddbFollowFile = gtk_check_button_new_with_label(_("Select corresponding file (according position or DLM)"));
+    CddbFollowFile = gtk_check_button_new_with_label(_("Select corresponding audio "
+        "file (according position or DLM if activated below)"));
     gtk_box_pack_start(GTK_BOX(vbox),CddbFollowFile,FALSE,FALSE,2);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(CddbFollowFile),CDDB_FOLLOW_FILE);
-    gtk_tooltips_set_tip(Tips,CddbFollowFile,_("If activated, when selecting a line in the list "
-        "of tracks name, the corresponding file in the main list will be also selected."),NULL);
+    gtk_tooltips_set_tip(Tips,CddbFollowFile,_("If activated, when selecting a "
+        "line in the list of tracks name, the corresponding audio file in the "
+        "main list will be also selected."),NULL);
 
     // Check box to use DLM
-    CddbUseDLM = gtk_check_button_new_with_label(_("Use DLM to match lines with files"));
+    CddbUseDLM = gtk_check_button_new_with_label(_("Use the Levenshtein algorithm "
+        "(DLM) to match lines (using title) with audio files (using filename)"));
     gtk_box_pack_start(GTK_BOX(vbox),CddbUseDLM,FALSE,FALSE,2);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(CddbUseDLM),CDDB_USE_DLM);
-    gtk_tooltips_set_tip(Tips,CddbUseDLM,_("When activating this option, matching of lines with files "
-        "is done by a fuzzy string matching, instead of direct position."),NULL);
+    gtk_tooltips_set_tip(Tips,CddbUseDLM,_("When activating this option, the "
+        "Levenshtein algorithm (DLM : Damerau-Levenshtein Metric) will be used "
+        "to match the CDDB title against every file name in the current folder, "
+        "and to select the best match. This will be used when selecting the "
+        "corresponding audio file, or applying cddb results, instead of using "
+        "directly the position order."),NULL);
 
 
     /*
