@@ -1,7 +1,7 @@
 /* config.h - 2000/06/21 */
 /*
  *  EasyTAG - Tag editor for MP3 and Ogg Vorbis files
- *  Copyright (C) 2000-2003  Jerome Couderc <j.couderc@ifrance.com>
+ *  Copyright (C) 2000-2003  Jerome Couderc <easytag@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
 #ifndef __CONFIG_H__
 #define __CONFIG_H__
 
+#include <gtk/gtk.h>
 
 /***************
  * Declaration *
@@ -54,12 +55,13 @@ gint     BROWSER_LINE_STYLE;
 gint     BROWSER_EXPANDER_STYLE;
 gint     WRITE_ID3V1_TAG;
 gint     WRITE_ID3V2_TAG;
+gint     WRITE_ID3_TAGS_IN_FLAC_FILE;
 gint     USE_ID3V2_PADDING;
 gint     STRIP_TAG_WHEN_EMPTY_FIELDS;
 gint     CONVERT_OLD_ID3V2_TAG_VERSION;
 gint     BROWSE_SUBDIR;
+gint     BROWSE_HIDDEN_DIR;
 gint     OPEN_SELECTED_BROWSER_NODE;
-gint     KEEP_TREE_BROWSER_IN_MEMORY;
 gint     SAVE_CONFIG_BEFORE_EXIT;
 
 /* User Interface */
@@ -75,12 +77,14 @@ gint     PANE_HANDLE_POSITION3;
 gint     SHOW_HEADER_INFO;
 
 gint     USE_COLORED_TOOLTIPS;
+gint     USE_NEW_LIST_STYLE;
 
 /* Scanner */
 gint    FTS_CONVERT_UNDERSCORE_AND_P20_INTO_SPACE;
 gint    FTS_CONVERT_SPACE_INTO_UNDERSCORE;
 gint    RFS_CONVERT_UNDERSCORE_AND_P20_INTO_SPACE;
 gint    RFS_CONVERT_SPACE_INTO_UNDERSCORE;
+gint    PFS_DONT_UPPER_SOME_WORDS;
 gint    OVERWRITE_TAG_FIELD;
 gint    SET_DEFAULT_COMMENT;
 gchar   *DEFAULT_COMMENT;
@@ -93,6 +97,10 @@ gint    SCANNER_WINDOW_Y;
 
 /* Misc */
 gint     REPLACE_ILLEGAL_CHARACTERS_IN_FILENAME;
+gint     FILENAME_EXTENSION_LOWER_CASE;
+gint     FILENAME_EXTENSION_UPPER_CASE;
+gint     FILENAME_EXTENSION_NO_CHANGE;
+gint     PRESERVE_MODIFICATION_TIME;
 gint     DATE_AUTO_COMPLETION;
 gint     NUMBER_TRACK_FORMATED;
 gint     NUMBER_TRACK_FORMATED_SPIN_BUTTON;
@@ -101,8 +109,8 @@ gint     SORTING_FILE_MODE;
 gint     SORTING_FILE_CASE_SENSITIVE;
 gint     USE_ISO_8859_1_CHARACTER_SET_TRANSLATION;
 gint     USE_CHARACTER_SET_TRANSLATION;
-gchar   *FILE_CHARACTER_SET;
-gchar   *USER_CHARACTER_SET;
+gchar   *FILE_READING_CHARACTER_SET;
+gchar   *FILE_WRITING_CHARACTER_SET;
 
 gint     MESSAGE_BOX_POSITION_NONE;
 gint     MESSAGE_BOX_POSITION_CENTER;
@@ -124,6 +132,11 @@ gint     PROCESS_ARTIST_FIELD;
 gint     PROCESS_ALBUM_FIELD;
 gint     PROCESS_GENRE_FIELD;
 gint     PROCESS_COMMENT_FIELD;
+gint     PROCESS_COMPOSER_FIELD;
+gint     PROCESS_ORIG_ARTIST_FIELD;
+gint     PROCESS_COPYRIGHT_FIELD;
+gint     PROCESS_URL_FIELD;
+gint     PROCESS_ENCODED_BY_FIELD;
 gint     PF_CONVERT_INTO_SPACE;
 gint     PF_CONVERT_SPACE;
 gint     PF_CONVERT;
@@ -168,6 +181,9 @@ gint     CDDB_WINDOW_WIDTH;
 gint     SET_CDDB_PANE_HANDLE_POSITION;
 gint     CDDB_PANE_HANDLE_POSITION;
 
+gint     CDDB_FOLLOW_FILE;
+gint     CDDB_USE_DLM;
+
 /* CDDB window */
 gint     CDDB_SEARCH_IN_ALL_FIELDS;
 gint     CDDB_SEARCH_IN_ARTIST_FIELD;
@@ -222,66 +238,62 @@ void Save_Config_Now (void);
 gboolean Create_Easytag_Directory (void);
 void     Setting_Create_Files     (void);
 
-void   Save_Glist_To_File     (GList *list, gchar *file);
-GList *Create_Glist_From_File (gchar *file);
-void   Free_Glist             (GList *list);
-
 
 /* MasksList */
-void   Save_Scan_Tag_Masks_List (GList *list);
-GList *Load_Scan_Tag_Masks_List (void);
+void   Save_Scan_Tag_Masks_List (GtkListStore *liststore, gint colnum);
+void   Load_Scan_Tag_Masks_List (GtkListStore *liststore, gint colnum, gchar **fallback);
 
 /* RenameFileMasksList */
-void   Save_Rename_File_Masks_List (GList *list);
-GList *Load_Rename_File_Masks_List (void);
+void   Save_Rename_File_Masks_List (GtkListStore *liststore, gint colnum);
+void   Load_Rename_File_Masks_List (GtkListStore *liststore, gint colnum, gchar **fallback);
 
 /* 'DefaultPathToMp3' combobox */
-GList *Load_Default_Path_To_MP3_List (void);
-void   Save_Default_Path_To_MP3_List (GList *list);
+void   Load_Default_Path_To_MP3_List (GtkListStore *liststore, gint colnum);
+void   Save_Default_Path_To_MP3_List (GtkListStore *liststore, gint colnum);
 
 /* 'DefaultComment' combobox */
-GList *Load_Default_Tag_Comment_Text_List (void);
-void   Save_Default_Tag_Comment_Text_List (GList *list);
+void   Load_Default_Tag_Comment_Text_List (GtkListStore *liststore, gint colnum);
+void   Save_Default_Tag_Comment_Text_List (GtkListStore *liststore, gint colnum);
 
 /* 'BrowserEntry' combobox */
-GList *Load_Path_Entry_List (void);
-void   Save_Path_Entry_List (GList *list);
+void   Load_Path_Entry_List (GtkListStore *liststore, gint colnum);
+void   Save_Path_Entry_List (GtkListStore *liststore, gint colnum);
 
 /* 'PlayListNameEntry' combobox */
-GList *Load_Play_List_Name_List (void);
-void   Save_Play_List_Name_List (GList *list);
+void   Load_Play_List_Name_List (GtkListStore *liststore, gint colnum);
+void   Save_Play_List_Name_List (GtkListStore *liststore, gint colnum);
 
 /* Run Program combobox (tree browser) */
-GList *Load_Run_Program_With_Directory_List (void);
-void   Save_Run_Program_With_Directory_List (GList *list);
+void   Load_Run_Program_With_Directory_List (GtkListStore *liststore, gint colnum);
+void   Save_Run_Program_With_Directory_List (GtkListStore *liststore, gint colnum);
 
 /* Run Program combobox (file browser) */
-GList *Load_Run_Program_With_File_List (void);
-void   Save_Run_Program_With_File_List (GList *list);
+void   Load_Run_Program_With_File_List (GtkListStore *liststore, gint colnum);
+void   Save_Run_Program_With_File_List (GtkListStore *liststore, gint colnum);
 
 /* 'FilePlayerEntry' combobox */
-GList *Load_Audio_File_Player_List (void);
-void   Save_Audio_File_Player_List (GList *list);
+void   Load_Audio_File_Player_List (GtkListStore *liststore, gint colnum);
+void   Save_Audio_File_Player_List (GtkListStore *liststore, gint colnum);
 
 /* 'SearchStringEntry' combobox */
-GList *Load_Search_File_List (void);
-void   Save_Search_File_List (GList *list);
+void   Load_Search_File_List (GtkListStore *liststore, gint colnum);
+void   Save_Search_File_List (GtkListStore *liststore, gint colnum);
 
 /* 'FileToLoad' combobox */
-GList *Load_File_To_Load_List (void);
-void   Save_File_To_Load_List (GList *list);
+void   Load_File_To_Load_List (GtkListStore *liststore, gint colnum);
+void   Save_File_To_Load_List (GtkListStore *liststore, gint colnum);
 
 /* 'PlayListContentMaskEntry' combobox */
-GList *Load_Playlist_Content_Mask_List (void);
-void   Save_Playlist_Content_Mask_List (GList *list);
+void   Load_Playlist_Content_Mask_List (GtkListStore *liststore, gint colnum);
+void   Save_Playlist_Content_Mask_List (GtkListStore *liststore, gint colnum);
 
 /* 'CddbSearchStringEntry' combobox */
-GList *Load_Cddb_Search_String_List (void);
-void   Save_Cddb_Search_String_List (GList *list);
+void   Load_Cddb_Search_String_List (GtkListStore *liststore, gint colnum);
+void   Save_Cddb_Search_String_List (GtkListStore *liststore, gint colnum);
 
 /* 'CddbSearchStringInResultEntry' combobox */
-GList *Load_Cddb_Search_String_In_Result_List (void);
-void   Save_Cddb_Search_String_In_Result_List (GList *list);
+void   Load_Cddb_Search_String_In_Result_List (GtkListStore *liststore, gint colnum);
+void   Save_Cddb_Search_String_In_Result_List (GtkListStore *liststore, gint colnum);
 
 
 #endif /* __CONFIG_H__ */
